Introduction
============

`memcached`_ is a cache daemon which keeps its data in RAM. It can be used by
other applications to speed up slow operations on the databases/data stores.

.. _memcached: http://memcached.org/

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
